import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{Dt as t,I as n,It as r,K as i,R as a,Rt as o,S as s,et as c,gt as l,j as u,k as d,nt as f}from"./vendor-vue-core-X6q-rGJs.js";import{L as p}from"./vendor-vueuse-B_IQhD9R.js";import{c as m,j as h,l as g,o as _,s as v}from"./vendor-reka-ui-CHPbCe4i.js";import{t as y}from"./src-Bx0QZVd-.js";var b=a({__name:`Slider`,props:{defaultValue:{},modelValue:{},disabled:{type:Boolean},orientation:{},dir:{},inverted:{type:Boolean},min:{},max:{},step:{},minStepsBetweenThumbs:{},thumbAlignment:{},asChild:{type:Boolean},as:{},name:{},required:{type:Boolean},class:{}},emits:[`update:modelValue`,`valueCommit`],setup(e,{emit:a}){let b=e,x=t(!1),setPressed=e=>{x.value=e},S=a,C=h(p(b,`class`),S);return(e,t)=>(c(),d(r(g),i({"data-slot":`slider`,class:r(y)(`relative flex w-full touch-none items-center select-none data-[disabled]:opacity-50`,`data-[orientation=vertical]:h-full data-[orientation=vertical]:min-h-44 data-[orientation=vertical]:w-auto data-[orientation=vertical]:flex-col`,b.class)},r(C),{onSlideStart:t[0]||=()=>setPressed(!0),onSlideMove:t[1]||=()=>setPressed(!0),onSlideEnd:t[2]||=()=>setPressed(!1)}),{default:l(({modelValue:e})=>[n(r(_),{"data-slot":`slider-track`,class:o(r(y)(`bg-node-stroke relative grow overflow-hidden rounded-full`,`cursor-pointer overflow-visible`,`before:absolute before:-inset-2 before:block before:bg-transparent`,`data-[orientation=horizontal]:h-0.5 data-[orientation=horizontal]:w-full`,`data-[orientation=vertical]:h-full data-[orientation=vertical]:w-0.5`))},{default:l(()=>[n(r(m),{"data-slot":`slider-range`,class:`absolute bg-node-component-surface-highlight data-[orientation=horizontal]:h-full data-[orientation=vertical]:w-full`})]),_:1},8,[`class`]),(c(!0),u(s,null,f(e,(e,t)=>(c(),d(r(v),{key:t,"data-slot":`slider-thumb`,class:o(r(y)(`bg-node-component-surface-highlight ring-node-component-surface-selected block size-3.5 shrink-0 rounded-full shadow-sm transition-[color,box-shadow]`,`cursor-grab`,`before:absolute before:-inset-1 before:block before:bg-transparent before:rounded-full`,`hover:ring-2 focus-visible:ring-2 focus-visible:outline-hidden disabled:pointer-events-none disabled:opacity-50`,{"cursor-grabbing":x.value}))},null,8,[`class`]))),128))]),_:1},16,[`class`]))}});export{b as t};
//# sourceMappingURL=Slider-DwzHlmqT.js.map