import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{c as t}from"./vendor-primevue-DxVRNMbC.js";import{A as n,D as r,It as i,O as a,R as o,Rt as s,Vt as c,et as l,j as u,k as d}from"./vendor-vue-core-X6q-rGJs.js";import{t as f}from"./types-DW97iHDr.js";import{i as p,n as m}from"./useFeatureFlags-CxRWjdi1.js";import{t as h}from"./src-Bx0QZVd-.js";import{t as g}from"./_plugin-vue_export-helper-fSAtQzP-.js";var _=!1;const v=r(()=>f?(p.value.firebase_config?.projectId)?.includes(`-dev`)??_:_);var y=g(o({__name:`SettingDialogHeader`,setup(e){let{flags:r}=m();return(e,o)=>(l(),u(`div`,null,[a(`h2`,{class:s(i(h)(i(r).teamWorkspacesEnabled?`px-6`:`px-4`))},[o[0]||=a(`i`,{class:`pi pi-cog`},null,-1),a(`span`,null,c(e.$t(`g.settings`)),1),i(v)?(l(),d(i(t),{key:0,value:`staging`,severity:`warn`,class:`ml-2 text-xs`})):n(``,!0)],2)]))}}),[[`__scopeId`,`data-v-b8af6861`]]);export{y as t};
//# sourceMappingURL=SettingDialogHeader-DkxX_y37.js.map