import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{j as t,s as n}from"./vendor-primevue-DxVRNMbC.js";import{A as r,D as i,G as a,I as o,It as s,K as c,R as l,Rt as u,Vt as d,b as f,et as p,gt as m,j as h,k as g,lt as _,ut as v}from"./vendor-vue-core-X6q-rGJs.js";import"./vendor-other-CyG3qq8S.js";import{t as y}from"./src-Bx0QZVd-.js";import{r as b}from"./widgetTypes-CUvQHbLo.js";import{o as x,r as S}from"./widgetPropFilter-AWF4Ovcm.js";import{t as C}from"./layout-uCC7X9bn.js";var w=[`for`],T=l({__name:`WidgetTextarea`,props:a({widget:{},placeholder:{default:``}},{modelValue:{default:``},modelModifiers:{}}),emits:[`update:modelValue`],setup(e){let a=v(e,`modelValue`),l=b(),T=i(()=>x(e.widget.options,S)),E=i(()=>e.widget.label||e.widget.name),D=_(),O=i(()=>e.widget.options?.read_only??!1);return(e,i)=>(p(),g(s(t),{variant:`in`,unstyled:s(l),class:u(s(y)(`rounded-lg space-y-1 focus-within:ring focus-within:ring-component-node-widget-background-highlighted transition-all`,e.widget.borderStyle))},{default:m(()=>[o(s(n),c(T.value,{id:s(D),modelValue:a.value,"onUpdate:modelValue":i[0]||=e=>a.value=e,class:s(y)(s(C),`size-full text-xs resize-none`),placeholder:e.placeholder,readonly:O.value,fluid:``,"data-capture-wheel":`true`,onPointerdownCapture:i[1]||=f(()=>{},[`stop`]),onPointermoveCapture:i[2]||=f(()=>{},[`stop`]),onPointerupCapture:i[3]||=f(()=>{},[`stop`]),onContextmenuCapture:i[4]||=f(()=>{},[`stop`])}),null,16,[`id`,`modelValue`,`class`,`placeholder`,`readonly`]),s(l)?r(``,!0):(p(),h(`label`,{key:0,for:s(D)},d(E.value),9,w))]),_:1},8,[`unstyled`,`class`]))}});export{T as default};
//# sourceMappingURL=WidgetTextarea-DHDGLjam.js.map