import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{Y as t,i as n,n as r,r as i,rt as a}from"./vendor-primevue-DxVRNMbC.js";import{A as o,D as s,F as c,I as l,It as u,O as d,R as f,Vt as p,et as m,gt as h,j as g,k as _}from"./vendor-vue-core-X6q-rGJs.js";import{W as v}from"./vendor-vueuse-B_IQhD9R.js";import{n as y}from"./vendor-i18n-B5g6Drzm.js";import{t as b}from"./Button-C7dWyQyS.js";import{or as x}from"./dialogService-Cqui0UMO.js";import{r as S}from"./signInSchema-xdSDWtCH.js";import{t as C}from"./PasswordFields-BcC2Idys.js";var w={class:`mb-2 text-base font-medium opacity-80`,for:`comfy-org-sign-up-email`},T={key:0,class:`text-red-500`},E=f({__name:`SignUpForm`,emits:[`submit`],setup(e,{emit:f}){let{t:E}=y(),D=x(),O=s(()=>D.loading),k=f,A=v(e=>{e.valid&&k(`submit`,e.values)},1500);return(e,s)=>(m(),_(u(n),{class:`flex flex-col gap-6`,resolver:u(r)(u(S)),onSubmit:u(A)},{default:h(e=>[l(u(i),{name:`email`,class:`flex flex-col gap-2`},{default:h(e=>[d(`label`,w,p(u(E)(`auth.signup.emailLabel`)),1),l(u(a),{"pt:root:id":`comfy-org-sign-up-email`,"pt:root:autocomplete":`email`,class:`h-10`,type:`text`,placeholder:u(E)(`auth.signup.emailPlaceholder`),invalid:e.invalid},null,8,[`placeholder`,`invalid`]),e.error?(m(),g(`small`,T,p(e.error.message),1)):o(``,!0)]),_:1}),l(C),O.value?(m(),_(u(t),{key:0,class:`mx-auto h-8 w-8`})):(m(),_(b,{key:1,type:`submit`,class:`mt-4 h-10 font-medium`,disabled:!e.valid},{default:h(()=>[c(p(u(E)(`auth.signup.signUpButton`)),1)]),_:2},1032,[`disabled`]))]),_:1},8,[`resolver`,`onSubmit`]))}});export{E as t};
//# sourceMappingURL=SignUpForm-CXmmLMxJ.js.map