import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{A as t,D as n,F as r,I as i,K as a,R as o,Rt as s,Vt as c,et as l,gt as u,j as d}from"./vendor-vue-core-X6q-rGJs.js";import"./vendor-other-CyG3qq8S.js";import"./vendor-reka-ui-CHPbCe4i.js";import{t as f}from"./Button-C7dWyQyS.js";import{o as p,t as m}from"./widgetPropFilter-AWF4Ovcm.js";var h={class:`flex flex-col gap-1`},g=o({__name:`WidgetButton`,props:{widget:{}},setup(e){let o=e,g=[...m,`iconClass`],_=n(()=>p(o.widget.options,g)),handleClick=()=>{o.widget.callback&&o.widget.callback()};return(e,n)=>(l(),d(`div`,h,[i(f,a({class:`text-base-foreground w-full border-0 bg-component-node-widget-background p-2`,"aria-label":e.widget.label,size:`sm`,variant:`textonly`},_.value,{onClick:handleClick}),{default:u(()=>[r(c(e.widget.label??e.widget.name)+` `,1),e.widget.options?.iconClass?(l(),d(`i`,{key:0,class:s(e.widget.options.iconClass)},null,2)):t(``,!0)]),_:1},16,[`aria-label`])]))}});export{g as default};
//# sourceMappingURL=WidgetButton-BDrcrBg3.js.map