import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import"./vendor-primevue-DxVRNMbC.js";import"./vendor-firebase-CdLSXhbt.js";import{A as t,Dt as n,F as r,I as i,O as a,R as o,Rt as s,S as c,Vt as l,et as u,gt as d,j as f,nt as p,o as m}from"./vendor-vue-core-X6q-rGJs.js";import"./vendor-other-CyG3qq8S.js";import"./useFeatureFlags-CxRWjdi1.js";import"./api-DQLKc1Xa.js";import"./vendor-markdown-Cola12Wc.js";import"./colorUtil-Cth7eqhK.js";import"./i18n-DjV_9lZM.js";import"./vendor-reka-ui-CHPbCe4i.js";import{t as h}from"./Button-C7dWyQyS.js";import{vn as g}from"./dialogService-Cqui0UMO.js";import"./systemStatsStore-D9aNY5gT.js";import"./useErrorHandling-BFB8eSj5.js";import"./dialogStore-CXD5Bcfy.js";import"./useCopyToClipboard-C74olorb.js";import"./vendor-tiptap-BXSIIPYY.js";import"./markdownRendererUtil-Bm7Umh6C.js";import"./useExternalLink-Cc30SNi3.js";var _={class:`flex h-full items-center justify-center p-6`},v={class:`max-w-[100vw] text-center lg:w-[500px]`},y={class:`mb-3 text-xl text-text-primary`},b={class:`mb-5 text-muted`},x={class:`mb-4 rounded bg-secondary-background px-3 py-2 text-left`},S={class:`mb-2 text-sm font-semibold text-text-primary`},C={class:`space-y-1.5 text-sm text-muted`},w={key:0,class:`mb-4 text-left`},T={key:0,class:`mt-2 rounded border-muted-background border p-4 font-mono text-xs text-muted-foreground break-all`},E={class:`mb-5 text-center text-sm text-gray-600`},D={href:`https://support.comfy.org`,class:`cursor-pointer text-blue-400 no-underline`,target:`_blank`,rel:`noopener noreferrer`},O={class:`flex flex-col gap-3`},k=o({__name:`CloudAuthTimeoutView`,props:{errorMessage:{}},setup(e){let o=m(),{logout:k}=g(),A=n(!1),handleRestart=async()=>{await k(),await o.replace({name:`cloud-login`})};return(e,n)=>(u(),f(`div`,_,[a(`div`,v,[a(`h2`,y,l(e.$t(`cloudOnboarding.authTimeout.title`)),1),a(`p`,b,l(e.$t(`cloudOnboarding.authTimeout.message`)),1),a(`div`,x,[a(`h3`,S,l(e.$t(`cloudOnboarding.authTimeout.troubleshooting`)),1),a(`ul`,C,[(u(!0),f(c,null,p(e.$tm(`cloudOnboarding.authTimeout.causes`),(e,t)=>(u(),f(`li`,{key:t,class:`flex gap-2`},[n[1]||=a(`span`,null,`•`,-1),a(`span`,null,l(e),1)]))),128))])]),e.errorMessage?(u(),f(`div`,w,[a(`button`,{class:`flex w-full items-center justify-between rounded bg-secondary-background px-4 py-2 text-sm text-text-secondary transition-colors hover:bg-secondary-background-hover border-0`,onClick:n[0]||=e=>A.value=!A.value},[a(`span`,null,l(e.$t(`cloudOnboarding.authTimeout.technicalDetails`)),1),a(`i`,{class:s([`pi`,A.value?`pi-chevron-up`:`pi-chevron-down`])},null,2)]),A.value?(u(),f(`div`,T,l(e.errorMessage),1)):t(``,!0)])):t(``,!0),a(`p`,E,[r(l(e.$t(`cloudOnboarding.authTimeout.helpText`))+` `,1),a(`a`,D,l(e.$t(`cloudOnboarding.authTimeout.supportLink`)),1),n[2]||=r(`. `)]),a(`div`,O,[i(h,{class:`w-full`,onClick:handleRestart},{default:d(()=>[r(l(e.$t(`cloudOnboarding.authTimeout.restart`)),1)]),_:1})])])]))}});export{k as default};
//# sourceMappingURL=CloudAuthTimeoutView-Q-AnNg0E.js.map