import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import"./vendor-primevue-DxVRNMbC.js";import"./vendor-firebase-CdLSXhbt.js";import"./vendor-other-CyG3qq8S.js";import"./useFeatureFlags-CxRWjdi1.js";import"./api-DQLKc1Xa.js";import"./vendor-markdown-Cola12Wc.js";import"./colorUtil-Cth7eqhK.js";import{o as t}from"./i18n-DjV_9lZM.js";import"./vendor-reka-ui-CHPbCe4i.js";import"./Button-C7dWyQyS.js";import{qt as n}from"./dialogService-Cqui0UMO.js";import"./systemStatsStore-D9aNY5gT.js";import"./useErrorHandling-BFB8eSj5.js";import"./dialogStore-CXD5Bcfy.js";import"./useCopyToClipboard-C74olorb.js";import"./vendor-tiptap-BXSIIPYY.js";import"./markdownRendererUtil-Bm7Umh6C.js";import"./useExternalLink-Cc30SNi3.js";import{r,t as i}from"./config-C71dnNHh.js";var a=`https://support.comfy.org/hc/en-us/requests/new`,o=`43066738713236`,s=r(),c=`${a}?${new URLSearchParams({ticket_form_id:o,[i.DISTRIBUTION]:s}).toString()}`,l=[{icon:`icon-[lucide--message-circle-question-mark]`,label:t(`actionbar.feedback`),tooltip:t(`actionbar.feedbackTooltip`),onClick:()=>{window.open(c,`_blank`,`noopener,noreferrer`)}}];n().registerExtension({name:`Comfy.Cloud.FeedbackButton`,actionBarButtons:l});
//# sourceMappingURL=cloudFeedbackTopbarButton-DZMGbRAW.js.map