import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{U as t}from"./vendor-vue-core-X6q-rGJs.js";const n=Symbol(),r=Symbol();function useHideLayoutField(){return t(r,!1)}export{n,useHideLayoutField as r,r as t};
//# sourceMappingURL=widgetTypes-CUvQHbLo.js.map