import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import"./vendor-primevue-DxVRNMbC.js";import{D as t,F as n,I as r,O as i,R as a,Vt as o,et as s,gt as c,j as l}from"./vendor-vue-core-X6q-rGJs.js";import"./vendor-other-CyG3qq8S.js";import"./i18n-DjV_9lZM.js";import"./vendor-reka-ui-CHPbCe4i.js";import{t as u}from"./Button-C7dWyQyS.js";import{t as d}from"./useCopyToClipboard-C74olorb.js";var f={class:`flex w-full items-center justify-between px-3 pb-4`},p={class:`flex w-full items-start justify-end gap-2 pr-1`},m=a({__name:`ImportFailedNodeFooter`,props:{conflictedPackages:{default:()=>[]}},setup(e){let{copyToClipboard:a}=d(),m=t(()=>{let t=[];return e.conflictedPackages.forEach(e=>{let n=e.conflicts.find(e=>e.type===`import_failed`);n?.required_value&&t.push(n.required_value)}),t.join(`

`)}),handleCopyError=()=>{a(m.value)};return(e,t)=>(s(),l(`div`,f,[i(`div`,p,[r(u,{variant:`secondary`,onClick:handleCopyError},{default:c(()=>[n(o(e.$t(`importFailed.copyError`)),1)]),_:1})])]))}});export{m as default};
//# sourceMappingURL=ImportFailedNodeFooter-tZSmcpzL.js.map