// Shim for extensions/core/load3d/LightingManager.ts
console.warn('[ComfyUI Notice] "extensions/core/load3d/LightingManager.js" is an internal module, not part of the public API. Future updates may break this import.');
export const LightingManager = window.comfyAPI.LightingManager.LightingManager;
