import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{D as t,O as n,R as r,Vt as i,_ as a,_t as o,et as s,j as c,ut as l}from"./vendor-vue-core-X6q-rGJs.js";var u={class:`grid grid-cols-[auto_1fr] gap-x-2 gap-y-1`},d={class:`content-center text-xs text-node-component-slot-text`},f={class:`content-center text-xs text-node-component-slot-text`},p={class:`content-center text-xs text-node-component-slot-text`},m={class:`content-center text-xs text-node-component-slot-text`},h=r({__name:`WidgetBoundingBox`,props:{modelValue:{default:()=>({x:0,y:0,width:512,height:512})},modelModifiers:{}},emits:[`update:modelValue`],setup(e){let r=l(e,`modelValue`),h=t({get:()=>r.value.x,set:e=>{r.value={...r.value,x:e}}}),g=t({get:()=>r.value.y,set:e=>{r.value={...r.value,y:e}}}),_=t({get:()=>r.value.width,set:e=>{r.value={...r.value,width:e}}}),v=t({get:()=>r.value.height,set:e=>{r.value={...r.value,height:e}}});return(e,t)=>(s(),c(`div`,u,[n(`label`,d,i(e.$t(`boundingBox.x`)),1),o(n(`input`,{"onUpdate:modelValue":t[0]||=e=>h.value=e,type:`number`,min:0,step:`1`,class:`h-7 rounded-lg border-none bg-component-node-widget-background px-2 text-xs text-component-node-foreground focus:outline-0`},null,512),[[a,h.value,void 0,{number:!0}]]),n(`label`,f,i(e.$t(`boundingBox.y`)),1),o(n(`input`,{"onUpdate:modelValue":t[1]||=e=>g.value=e,type:`number`,min:0,step:`1`,class:`h-7 rounded-lg border-none bg-component-node-widget-background px-2 text-xs text-component-node-foreground focus:outline-0`},null,512),[[a,g.value,void 0,{number:!0}]]),n(`label`,p,i(e.$t(`boundingBox.width`)),1),o(n(`input`,{"onUpdate:modelValue":t[2]||=e=>_.value=e,type:`number`,min:1,step:`1`,class:`h-7 rounded-lg border-none bg-component-node-widget-background px-2 text-xs text-component-node-foreground focus:outline-0`},null,512),[[a,_.value,void 0,{number:!0}]]),n(`label`,m,i(e.$t(`boundingBox.height`)),1),o(n(`input`,{"onUpdate:modelValue":t[3]||=e=>v.value=e,type:`number`,min:1,step:`1`,class:`h-7 rounded-lg border-none bg-component-node-widget-background px-2 text-xs text-component-node-foreground focus:outline-0`},null,512),[[a,v.value,void 0,{number:!0}]])]))}});export{h as t};
//# sourceMappingURL=WidgetBoundingBox-BZEBhXkV.js.map