import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import"./vendor-primevue-DxVRNMbC.js";import"./vendor-firebase-CdLSXhbt.js";import{F as t,I as n,It as r,O as i,R as a,S as o,Vt as s,et as c,gt as l,j as u,rt as d,t as f}from"./vendor-vue-core-X6q-rGJs.js";import"./vendor-other-CyG3qq8S.js";import"./useFeatureFlags-CxRWjdi1.js";import"./api-DQLKc1Xa.js";import"./vendor-markdown-Cola12Wc.js";import"./colorUtil-Cth7eqhK.js";import{n as p}from"./vendor-i18n-B5g6Drzm.js";import"./i18n-DjV_9lZM.js";import"./vendor-reka-ui-CHPbCe4i.js";import{t as m}from"./Button-C7dWyQyS.js";import"./dialogService-Cqui0UMO.js";import"./systemStatsStore-D9aNY5gT.js";import"./useErrorHandling-BFB8eSj5.js";import{t as h}from"./_plugin-vue_export-helper-fSAtQzP-.js";import"./dialogStore-CXD5Bcfy.js";import"./useCopyToClipboard-C74olorb.js";import"./vendor-tiptap-BXSIIPYY.js";import"./markdownRendererUtil-Bm7Umh6C.js";import"./useExternalLink-Cc30SNi3.js";import{t as g}from"./GlobalToast-rP3SQPR_.js";import{t as _}from"./BaseViewTemplate-Cdt_Rbxk.js";var v=``+new URL(`thumbnail-imMA3y7Z.png`,import.meta.url).href,y=``+new URL(`video-BvOHf4P9.mp4`,import.meta.url).href,b=``+new URL(`images/comfy-cloud-logo.svg`,import.meta.url).href,x={},S={class:`mx-auto flex h-[7%] max-h-[70px] w-5/6 items-end`},C=[`alt`];function _sfc_render(e,t){return c(),u(`div`,S,[i(`img`,{src:b,alt:e.$t(`subscription.comfyCloudLogo`),class:`h-3/4 max-h-10 w-auto`},null,8,C)])}var w=h(x,[[`render`,_sfc_render]]),T={class:`mx-auto flex h-[5%] max-h-[60px] w-5/6 items-start gap-2.5`},E={href:`https://www.comfy.org/terms-of-service`,target:`_blank`,class:`cursor-pointer text-sm text-gray-600 no-underline`},D={href:`https://www.comfy.org/privacy-policy`,target:`_blank`,class:`cursor-pointer text-sm text-gray-600 no-underline`},O={href:`https://support.comfy.org`,class:`cursor-pointer text-sm text-gray-600 no-underline`,target:`_blank`,rel:`noopener noreferrer`},k=a({__name:`CloudTemplateFooter`,setup(e){let{t}=p();return(e,n)=>(c(),u(`footer`,T,[i(`a`,E,s(r(t)(`auth.login.termsLink`)),1),i(`a`,D,s(r(t)(`auth.login.privacyLink`)),1),i(`a`,O,s(r(t)(`cloudFooter_needHelp`)),1)]))}}),A={class:`flex`},j={class:`relative hidden flex-1 overflow-hidden bg-black lg:block`},M=[`poster`],N=[`src`],P={class:`absolute inset-0 flex items-center justify-center text-center text-white`},F={class:`font-abcrom hero-title font-black uppercase italic`},I={class:`m-2 text-center text-xl text-white`},L={class:`m-0 text-center text-xl text-white`},R={class:`absolute inset-0 flex flex-col justify-end px-14 pb-[64px]`},z={class:`flex items-center justify-end`},B={class:`flex items-center gap-3`},V={class:`text-md text-white`},H=a({__name:`CloudTemplate`,setup(e){let{t:a}=p(),handleDownloadClick=()=>{window.open(`https://www.comfy.org/download`,`_blank`)};return(e,o)=>(c(),u(`div`,A,[n(_,{dark:``,class:`flex-1`},{header:l(()=>[n(w)]),footer:l(()=>[n(k)]),default:l(()=>[d(e.$slots,`default`)]),_:3}),i(`div`,j,[i(`video`,{class:`absolute inset-0 h-full w-full object-cover`,autoplay:``,muted:``,loop:``,playsinline:``,poster:r(v)},[i(`source`,{src:r(y),type:`video/mp4`},null,8,N)],8,M),o[0]||=i(`div`,{class:`absolute inset-0 h-full w-full bg-black/30`},null,-1),i(`div`,P,[i(`div`,null,[i(`h1`,F,s(r(a)(`cloudStart_title`)),1),i(`p`,I,s(r(a)(`cloudStart_desc`)),1),i(`p`,L,s(r(a)(`cloudStart_explain`)),1)])]),i(`div`,R,[i(`div`,z,[i(`div`,B,[i(`p`,V,s(r(a)(`cloudStart_wantToRun`)),1),n(m,{type:`button`,class:`h-10 bg-black font-bold text-white`,variant:`secondary`,onClick:handleDownloadClick},{default:l(()=>[t(s(r(a)(`cloudStart_download`)),1)]),_:1})])])])])]))}}),U=a({__name:`CloudLayoutView`,setup(e){return(e,t)=>(c(),u(o,null,[n(H,null,{default:l(()=>[n(r(f))]),_:1}),n(g)],64))}});export{U as default};
//# sourceMappingURL=CloudLayoutView-D3sAcX7r.js.map