import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{P as t}from"./vendor-primevue-DxVRNMbC.js";import"./vendor-firebase-CdLSXhbt.js";import{A as n,D as r,F as i,I as a,It as o,O as s,R as c,Rt as l,S as u,Vt as d,et as f,gt as p,j as m,nt as h,ut as g}from"./vendor-vue-core-X6q-rGJs.js";import"./vendor-other-CyG3qq8S.js";import"./useFeatureFlags-CxRWjdi1.js";import"./api-DQLKc1Xa.js";import"./vendor-markdown-Cola12Wc.js";import"./colorUtil-Cth7eqhK.js";import"./i18n-DjV_9lZM.js";import"./vendor-reka-ui-CHPbCe4i.js";import{t as _}from"./Button-C7dWyQyS.js";import{i as v}from"./dialogService-Cqui0UMO.js";import"./systemStatsStore-D9aNY5gT.js";import"./useErrorHandling-BFB8eSj5.js";import"./dialogStore-CXD5Bcfy.js";import"./useCopyToClipboard-C74olorb.js";import"./vendor-tiptap-BXSIIPYY.js";import"./markdownRendererUtil-Bm7Umh6C.js";import"./useExternalLink-Cc30SNi3.js";var y={class:`w-113 max-w-md p-4 space-y-4`},b={class:`text-sm text-muted-foreground leading-tight`},x={class:`text-base-foreground font-medium`},S={class:`space-y-2`},C={class:`flex items-center gap-2 flex-1 min-w-0 text-wrap`},w={class:`flex items-center justify-center w-8 h-8 rounded-lg flex-shrink-0 bg-secondary-background border border-border-subtle`},T={key:1,class:`text-xs font-normal text-base-foreground`},E={class:`flex flex-col gap-0.5 min-w-0 flex-1`},D={class:`text-sm font-normal text-base-foreground leading-tight`},O={class:`text-sm font-normal text-muted-foreground leading-tight`},k=c({__name:`ValueControlPopover`,props:{modelValue:{},modelModifiers:{}},emits:[`update:modelValue`],setup(e){let c=v(),k=[{mode:`fixed`,icon:`icon-[lucide--pencil-off]`,title:`fixed`,description:`fixedDesc`},{mode:`increment`,text:`+1`,title:`increment`,description:`incrementDesc`},{mode:`decrement`,text:`-1`,title:`decrement`,description:`decrementDesc`},{mode:`randomize`,icon:`icon-[lucide--shuffle]`,title:`randomize`,description:`randomizeDesc`}],A=r(()=>c.get(`Comfy.WidgetControlMode`)),j=g(e,`modelValue`);return(e,r)=>(f(),m(`div`,y,[s(`div`,b,[i(d(e.$t(`widgets.valueControl.header.prefix`))+` `,1),s(`span`,x,d(A.value===`before`?e.$t(`widgets.valueControl.header.before`):e.$t(`widgets.valueControl.header.after`)),1),i(` `+d(e.$t(`widgets.valueControl.header.postfix`)),1)]),s(`div`,S,[(f(),m(u,null,h(k,i=>a(_,{key:i.mode,as:`label`,variant:`textonly`,size:`lg`,class:`flex w-full h-[unset] text-left items-center justify-between py-2 gap-7`,for:i.mode},{default:p(()=>[s(`div`,C,[s(`div`,w,[i.icon?(f(),m(`i`,{key:0,class:l([i.icon,`text-base text-base-foreground`])},null,2)):n(``,!0),i.text?(f(),m(`span`,T,d(i.text),1)):n(``,!0)]),s(`div`,E,[s(`div`,D,[s(`span`,null,d(e.$t(`widgets.valueControl.${i.title}`)),1)]),s(`div`,O,d(e.$t(`widgets.valueControl.${i.description}`)),1)])]),a(o(t),{modelValue:j.value,"onUpdate:modelValue":r[0]||=e=>j.value=e,class:`shrink`,"input-id":i.mode,value:i.mode},null,8,[`modelValue`,`input-id`,`value`])]),_:2},1032,[`for`])),64))])]))}});export{k as default};
//# sourceMappingURL=ValueControlPopover-C5kdd3VH.js.map