import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{Dt as t,It as n,O as r,R as i,Rt as a,Z as o,_t as s,et as c,j as l,q as u,rt as d,v as f}from"./vendor-vue-core-X6q-rGJs.js";import{n as p}from"./types-DW97iHDr.js";import{n as m,t as h}from"./envUtil-CcEF5ALS.js";var g={class:`flex w-full grow items-center justify-center overflow-auto`},_=i({__name:`BaseViewTemplate`,props:{dark:{type:Boolean,default:!1}},setup(e){let i={color:`rgba(0, 0, 0, 0)`,symbolColor:`#d4d4d4`},_={color:`rgba(0, 0, 0, 0)`,symbolColor:`#171717`},v=t(null);return o(async()=>{p&&(await u(),h().changeTheme({...e.dark?i:_,height:v.value?.getBoundingClientRect().height??0}))}),(e,t)=>(c(),l(`div`,{class:a([`flex h-svh w-screen flex-col font-sans`,[e.dark?`dark-theme bg-neutral-900 text-neutral-300`:`bg-neutral-300 text-neutral-900`]])},[s(r(`div`,{ref_key:`topMenuRef`,ref:v,class:`app-drag h-(--comfy-topbar-height) w-full`},null,512),[[f,n(m)()]]),r(`div`,g,[d(e.$slots,`default`)])],2))}});export{_ as t};
//# sourceMappingURL=BaseViewTemplate-Cdt_Rbxk.js.map