import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{f as t,q as n}from"./vendor-primevue-DxVRNMbC.js";import{I as r,It as i,O as a,R as o,Rt as s,et as c,gt as l,k as u,rt as d}from"./vendor-vue-core-X6q-rGJs.js";var f={class:`flex h-full w-full flex-col gap-2`},p=o({__name:`PanelTemplate`,props:{value:{},class:{}},setup(e){let o=e;return(e,p)=>(c(),u(i(t),{value:o.value,class:s([`h-full w-full`,o.class])},{default:l(()=>[a(`div`,f,[d(e.$slots,`header`),r(i(n),{class:`h-0 grow pr-2`},{default:l(()=>[d(e.$slots,`default`)]),_:3}),d(e.$slots,`footer`)])]),_:3},8,[`value`,`class`]))}});export{p as t};
//# sourceMappingURL=PanelTemplate-NIaSENoZ.js.map