import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{A as t,F as n,It as r,O as i,R as a,Rt as o,S as s,Vt as c,b as l,et as u,j as d,rt as f}from"./vendor-vue-core-X6q-rGJs.js";import{t as p}from"./src-Bx0QZVd-.js";import{r as m}from"./widgetTypes-CUvQHbLo.js";var h={class:`grid grid-cols-subgrid min-w-0 justify-between gap-1 text-node-component-slot-text`},g={key:0,class:`truncate content-center-safe`},_={class:`relative min-w-0 flex-1`},v=a({__name:`WidgetLayoutField`,props:{widget:{}},setup(e){let a=m();return(e,m)=>(u(),d(`div`,h,[r(a)?t(``,!0):(u(),d(`div`,g,[e.widget.name?(u(),d(s,{key:0},[n(c(e.widget.label||e.widget.name),1)],64)):t(``,!0)])),i(`div`,_,[i(`div`,{class:o(r(p)(`cursor-default min-w-0 rounded-lg focus-within:ring focus-within:ring-component-node-widget-background-highlighted transition-all`,e.widget.borderStyle)),onPointerdown:m[0]||=l(()=>{},[`stop`]),onPointermove:m[1]||=l(()=>{},[`stop`]),onPointerup:m[2]||=l(()=>{},[`stop`])},[f(e.$slots,`default`)],34)])]))}});export{v as t};
//# sourceMappingURL=WidgetLayoutField-AgGHRP9B.js.map