import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{rt as t}from"./vendor-primevue-DxVRNMbC.js";import{D as n,G as r,I as i,It as a,K as o,R as s,et as c,gt as l,k as u,ut as d}from"./vendor-vue-core-X6q-rGJs.js";import"./vendor-other-CyG3qq8S.js";import{t as f}from"./src-Bx0QZVd-.js";import{o as p,r as m}from"./widgetPropFilter-AWF4Ovcm.js";import{t as h}from"./layout-uCC7X9bn.js";import{t as g}from"./WidgetLayoutField-AgGHRP9B.js";var _=s({__name:`WidgetInputText`,props:r({widget:{}},{modelValue:{default:``},modelModifiers:{}}),emits:[`update:modelValue`],setup(e){let r=e,s=d(e,`modelValue`),_=n(()=>p(r.widget.options,m));return(e,n)=>(c(),u(g,{widget:e.widget},{default:l(()=>[i(a(t),o({modelValue:s.value,"onUpdate:modelValue":n[0]||=e=>s.value=e},_.value,{class:a(f)(a(h),`w-full text-xs py-2 px-4`),"aria-label":e.widget.name,size:`small`,pt:{root:`truncate min-w-[4ch]`}}),null,16,[`modelValue`,`class`,`aria-label`])]),_:1},8,[`widget`]))}});export{_ as default};
//# sourceMappingURL=WidgetInputText-C3eHw505.js.map