import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{It as t}from"./vendor-vue-core-X6q-rGJs.js";import{L as n}from"./api-DQLKc1Xa.js";var isNodeMissingDefinition=(e,t)=>{let n=e?.type;return n?!t[n]:!1};const collectMissingNodes=(e,r)=>{if(!e)return[];let i=t(r);return n(e,e=>isNodeMissingDefinition(e,i))},graphHasMissingNodes=(e,t)=>collectMissingNodes(e,t).length>0;export{graphHasMissingNodes as t};
//# sourceMappingURL=graphHasMissingNodes-DBqICxdS.js.map