import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import"./vendor-primevue-DxVRNMbC.js";import"./vendor-firebase-CdLSXhbt.js";import{D as t,It as n,R as r,et as i,k as a,ot as o}from"./vendor-vue-core-X6q-rGJs.js";import"./vendor-other-CyG3qq8S.js";import"./useFeatureFlags-CxRWjdi1.js";import"./api-DQLKc1Xa.js";import"./vendor-markdown-Cola12Wc.js";import"./colorUtil-Cth7eqhK.js";import"./i18n-DjV_9lZM.js";import"./vendor-reka-ui-CHPbCe4i.js";import"./Button-C7dWyQyS.js";import{ln as s}from"./dialogService-Cqui0UMO.js";import"./systemStatsStore-D9aNY5gT.js";import"./useErrorHandling-BFB8eSj5.js";import"./dialogStore-CXD5Bcfy.js";import"./useCopyToClipboard-C74olorb.js";import"./vendor-tiptap-BXSIIPYY.js";import"./markdownRendererUtil-Bm7Umh6C.js";import"./useExternalLink-Cc30SNi3.js";import{t as c}from"./ComfyQueueButton-CJRzkjTx.js";import{t as l}from"./SubscribeToRun-BGDt0HAk.js";var u=r({__name:`CloudRunButtonWrapper`,setup(e){let{isActiveSubscription:r}=s(),u=t(()=>r.value?c:l);return(e,t)=>(i(),a(o(u.value),{key:n(r)?`queue`:`subscribe`}))}});export{u as default};
//# sourceMappingURL=CloudRunButtonWrapper-2P_tJOEZ.js.map