.dot-animation[data-v-ec0691c8]{animation:1s ease-in-out infinite dot-pulse-ec0691c8}@keyframes dot-pulse-ec0691c8{0%,80%,to{opacity:.3}40%{opacity:1}}.content-divider[data-v-1d39213b]{z-index:1;border:none;flex-shrink:0;margin:0;padding:0;display:inline-block;position:relative}.content-divider--horizontal[data-v-1d39213b]{width:100%;height:var(--4bb7c524)}.content-divider--vertical[data-v-1d39213b]{height:100%;width:var(--4bb7c524)}
