import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{It as t,O as n,R as r,Vt as i,et as a,j as o}from"./vendor-vue-core-X6q-rGJs.js";import{n as s}from"./vendor-i18n-B5g6Drzm.js";import{t as c}from"./_plugin-vue_export-helper-fSAtQzP-.js";var l={class:`cloud-sorry-contact-support`},u=c(r({__name:`CloudSorryContactSupportView`,setup(e){let{t:r}=s();return(e,s)=>(a(),o(`div`,l,[n(`h1`,null,i(t(r)(`cloudSorryContactSupport_title`)),1)]))}}),[[`__scopeId`,`data-v-c3fa108d`]]);export{u as default};
//# sourceMappingURL=CloudSorryContactSupportView-BOHMM9UZ.js.map