import"./vendor-primevue-DxVRNMbC.js";import"./vendor-other-CyG3qq8S.js";import"./api-DQLKc1Xa.js";import"./vendor-markdown-Cola12Wc.js";import"./colorUtil-Cth7eqhK.js";import"./i18n-DjV_9lZM.js";import{n as e,r as t,t as n}from"./auth-C8aVxlew.js";export{n as getSurveyCompletedStatus};