.settings-tab-panels{padding-top:0!important}@media (prefers-reduced-motion:no-preference){.setting-highlight{animation:1.5s ease-in-out setting-highlight-pulse}}@keyframes setting-highlight-pulse{0%,to{background-color:#0000}30%{background-color:color-mix(in srgb,var(--p-primary-color)15%,transparent)}}.settings-container[data-v-cfaa2565]{width:60vw;max-width:64rem;height:70vh;display:flex;overflow:hidden}.settings-content[data-v-cfaa2565]{overflow-x:auto}@media (max-width:768px){.settings-container[data-v-cfaa2565]{flex-direction:column;width:80vw;height:auto}.settings-sidebar[data-v-cfaa2565]{width:100%}.settings-content[data-v-cfaa2565]{height:350px}}.settings-sidebar[data-v-cfaa2565] .p-listbox-option-group:first-child{display:none}
