import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{D as t,R as n,et as r,k as i}from"./vendor-vue-core-X6q-rGJs.js";import{n as a}from"./vendor-i18n-B5g6Drzm.js";import{t as o}from"./TopbarBadge-E4og8RTb.js";var s=n({__name:`CloudBadge`,props:{displayMode:{default:`full`},reverseOrder:{type:Boolean,default:!1},noPadding:{type:Boolean,default:!1},backgroundColor:{default:`var(--comfy-menu-bg)`}},setup(e){let{t:n}=a(),s=t(()=>({label:n(`g.beta`),text:`Comfy Cloud`}));return(e,t)=>(r(),i(o,{badge:s.value,"display-mode":e.displayMode,"reverse-order":e.reverseOrder,"no-padding":e.noPadding,"background-color":e.backgroundColor},null,8,[`badge`,`display-mode`,`reverse-order`,`no-padding`,`background-color`]))}});export{s as t};
//# sourceMappingURL=CloudBadge-C3lQO8Xo.js.map