/*! tailwindcss v4.1.12 | MIT License | https://tailwindcss.com */
.form-input[data-v-85c28908] .input-slider .p-inputnumber input,.form-input[data-v-85c28908] .input-slider .slider-part{width:calc(var(--spacing,.25rem)*20)}.form-input[data-v-85c28908] .input-knob .p-inputnumber input,.form-input[data-v-85c28908] .input-knob .knob-part{width:calc(var(--spacing,.25rem)*32)}:is(.form-input[data-v-85c28908] .p-inputtext,.form-input[data-v-85c28908] .p-select){width:calc(var(--spacing,.25rem)*44)}
