import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{i as t,n}from"./vendor-primevue-DxVRNMbC.js";import"./vendor-firebase-CdLSXhbt.js";import{Dt as r,F as i,I as a,It as o,R as s,Vt as c,et as l,gt as u,k as d}from"./vendor-vue-core-X6q-rGJs.js";import"./vendor-other-CyG3qq8S.js";import"./useFeatureFlags-CxRWjdi1.js";import"./api-DQLKc1Xa.js";import"./vendor-markdown-Cola12Wc.js";import"./colorUtil-Cth7eqhK.js";import"./i18n-DjV_9lZM.js";import"./vendor-reka-ui-CHPbCe4i.js";import{t as f}from"./Button-C7dWyQyS.js";import{vn as p}from"./dialogService-Cqui0UMO.js";import"./systemStatsStore-D9aNY5gT.js";import"./useErrorHandling-BFB8eSj5.js";import"./dialogStore-CXD5Bcfy.js";import"./useCopyToClipboard-C74olorb.js";import"./vendor-tiptap-BXSIIPYY.js";import"./markdownRendererUtil-Bm7Umh6C.js";import"./useExternalLink-Cc30SNi3.js";import{i as m}from"./signInSchema-xdSDWtCH.js";import{t as h}from"./PasswordFields-BcC2Idys.js";var g=s({__name:`UpdatePasswordContent`,props:{onSuccess:{type:Function}},setup(e){let s=p(),g=r(!1),onSubmit=async t=>{if(t.valid){g.value=!0;try{await s.updatePassword(t.values.password),e.onSuccess()}finally{g.value=!1}}};return(e,r)=>(l(),d(o(t),{class:`flex w-96 flex-col gap-6`,resolver:o(n)(o(m)),onSubmit},{default:u(()=>[a(h),a(f,{type:`submit`,class:`mt-4 h-10 font-medium`,loading:g.value},{default:u(()=>[i(c(e.$t(`userSettings.updatePassword`)),1)]),_:1},8,[`loading`])]),_:1},8,[`resolver`]))}});export{g as default};
//# sourceMappingURL=UpdatePasswordContent-vqOq0kGF.js.map