import{t as e}from"./src-Bx0QZVd-.js";const t=e([`not-disabled:bg-component-node-widget-background`,`not-disabled:text-component-node-foreground`,`border-none`,`rounded-lg`]);export{t};
//# sourceMappingURL=layout-uCC7X9bn.js.map