import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{t}from"./vendor-primevue-DxVRNMbC.js";import{D as n,G as r,I as i,It as a,O as o,R as s,et as c,j as l,ut as u}from"./vendor-vue-core-X6q-rGJs.js";var d={class:`flex flex-col gap-1`},f={class:`max-h-[48rem] rounded border p-4`},p=s({__name:`WidgetChart`,props:r({widget:{}},{modelValue:{required:!0},modelModifiers:{}}),emits:[`update:modelValue`],setup(e){let r=u(e,`modelValue`),s=e,p=n(()=>s.widget.options?.type??`line`),m=n(()=>r.value||{labels:[],datasets:[]}),h=n(()=>({responsive:!0,maintainAspectRatio:!1,plugins:{legend:{labels:{color:`#FFF`,usePointStyle:!0,pointStyle:`circle`}}},scales:{x:{ticks:{color:`#9FA2BD`},grid:{display:!0,color:`#9FA2BD`,drawTicks:!1,drawOnChartArea:!0,drawBorder:!1},border:{display:!0,color:`#9FA2BD`}},y:{ticks:{color:`#9FA2BD`},grid:{display:!1,drawTicks:!1,drawOnChartArea:!1,drawBorder:!1},border:{display:!0,color:`#9FA2BD`}}}}));return(e,n)=>(c(),l(`div`,d,[o(`div`,f,[i(a(t),{type:p.value,data:m.value,options:h.value,"aria-label":`${e.widget.name||e.$t(`g.chart`)} - ${p.value} ${e.$t(`g.chartLowercase`)}`},null,8,[`type`,`data`,`options`,`aria-label`])])]))}});export{p as default};
//# sourceMappingURL=WidgetChart-EEnRMXLx.js.map