import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{It as t,O as n,R as r,Vt as i,et as a,j as o}from"./vendor-vue-core-X6q-rGJs.js";import{t as s}from"./types-DW97iHDr.js";var c={class:`flex w-full items-center justify-between p-4`},l={class:`flex items-center gap-2`},u={class:`m-0 text-sm`},d=r({__name:`MissingNodesHeader`,setup(e){return(e,r)=>(a(),o(`div`,c,[n(`div`,l,[r[0]||=n(`i`,{class:`icon-[lucide--triangle-alert] text-warning-background`},null,-1),n(`p`,u,i(t(s)?e.$t(`missingNodes.cloud.title`):e.$t(`missingNodes.oss.title`)),1)])]))}});export{d as default};
//# sourceMappingURL=MissingNodesHeader-CESmhc9L.js.map