import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{H as t}from"./vendor-primevue-DxVRNMbC.js";import{D as n,Dt as r,It as i,R as a,et as o,k as s}from"./vendor-vue-core-X6q-rGJs.js";var c=a({__name:`UserAvatar`,props:{photoUrl:{},ariaLabel:{}},setup(e){let a=r(!1),handleImageError=()=>{a.value=!0},c=n(()=>e.photoUrl&&!a.value);return(e,n)=>(o(),s(i(t),{class:`bg-interface-panel-selected-surface`,image:e.photoUrl??void 0,icon:c.value?void 0:`icon-[lucide--user]`,"pt:icon:class":{"size-4":!c.value},shape:`circle`,"aria-label":e.ariaLabel??e.$t(`auth.login.userAvatar`),onError:handleImageError},null,8,[`image`,`icon`,`pt:icon:class`,`aria-label`]))}});export{c as t};
//# sourceMappingURL=UserAvatar-B_ZX16Wt.js.map