import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{Bt as t,D as n,R as r,Vt as i,et as a,j as o}from"./vendor-vue-core-X6q-rGJs.js";var s=r({__name:`WorkspaceProfilePic`,props:{workspaceName:{}},setup(e){let r=n(()=>e.workspaceName?.charAt(0)?.toUpperCase()??`?`),s=n(()=>{let e=r.value.charCodeAt(0);function mulberry32(e){return function(){let t=e+=1831565813;return t=Math.imul(t^t>>>15,t|1),t^=t+Math.imul(t^t>>>7,t|61),((t^t>>>14)>>>0)/4294967296}}let t=mulberry32(e),n=Math.floor(t()*360),i=(n+40+Math.floor(t()*80))%360,a=65+Math.floor(t()*20),o=55+Math.floor(t()*15);return`linear-gradient(135deg, hsl(${n}, ${a}%, ${o}%), hsl(${i}, ${a}%, ${o}%))`});return(e,n)=>(a(),o(`div`,{class:`flex size-8 items-center justify-center rounded-md text-base font-semibold text-white`,style:t({background:s.value,textShadow:`0 1px 2px rgba(0, 0, 0, 0.2)`})},i(r.value),5))}});export{s as t};
//# sourceMappingURL=WorkspaceProfilePic-CujGt-nj.js.map