import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{D as t,F as n,O as r,R as i,Vt as a,_t as o,at as s,et as c,gt as l,k as u}from"./vendor-vue-core-X6q-rGJs.js";import{t as d}from"./types-DW97iHDr.js";import{c as f,r as p}from"./vendor-vueuse-B_IQhD9R.js";import{n as m}from"./vendor-i18n-B5g6Drzm.js";import{t as h}from"./telemetry-KciZP3tz.js";import{t as g}from"./Button-C7dWyQyS.js";import{ln as _}from"./dialogService-Cqui0UMO.js";var v=i({__name:`SubscribeToRun`,setup(e){let{t:i}=m(),v=f(p).greaterOrEqual(`md`),y=t(()=>v.value?i(`subscription.subscribeToRunFull`):i(`subscription.subscribeToRun`)),{showSubscriptionDialog:b}=_(),handleSubscribeToRun=()=>{d&&h()?.trackRunButton({subscribe_to_run:!0}),b()};return(e,t)=>{let i=s(`tooltip`);return o((c(),u(g,{class:`subscribe-to-run-button whitespace-nowrap`,variant:`primary`,size:`sm`,style:{background:`var(--color-subscription-button-gradient)`,color:`var(--color-white)`,borderColor:`transparent`},"data-testid":`subscribe-to-run-button`,onClick:handleSubscribeToRun},{default:l(()=>[t[0]||=r(`i`,{class:`pi pi-lock`},null,-1),n(` `+a(y.value),1)]),_:1})),[[i,{value:e.$t(`subscription.subscribeToRunFull`),showDelay:600},void 0,{bottom:!0}]])}}});export{v as t};
//# sourceMappingURL=SubscribeToRun-BGDt0HAk.js.map