import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import"./vendor-primevue-DxVRNMbC.js";import{A as t,F as n,I as r,O as i,R as a,Vt as o,et as s,gt as c,j as l,k as u}from"./vendor-vue-core-X6q-rGJs.js";import"./vendor-other-CyG3qq8S.js";import"./i18n-DjV_9lZM.js";import"./vendor-reka-ui-CHPbCe4i.js";import{t as d}from"./Button-C7dWyQyS.js";import{t as f}from"./dialogStore-CXD5Bcfy.js";import{t as p}from"./useExternalLink-Cc30SNi3.js";var m={class:`flex w-full items-center justify-between px-3 py-4`},h={class:`flex w-full items-center justify-between gap-2 pr-1`},g=a({__name:`NodeConflictFooter`,props:{buttonText:{default:void 0},onButtonClick:{type:Function,default:void 0}},setup(e){let a=e,{buildDocsUrl:g}=p(),_=f(),handleConflictInfoClick=()=>{window.open(g(`/troubleshooting/custom-node-issues`,{includeLocale:!0}),`_blank`)},handleButtonClick=()=>{_.closeDialog({key:`global-node-conflict`}),a.onButtonClick&&a.onButtonClick()};return(e,f)=>(s(),l(`div`,m,[i(`div`,h,[r(d,{variant:`muted-textonly`,size:`sm`,class:`text-sm`,onClick:handleConflictInfoClick},{default:c(()=>[f[0]||=i(`i`,{class:`pi pi-info-circle`},null,-1),n(` `+o(e.$t(`manager.conflicts.conflictInfoTitle`)),1)]),_:1}),a.buttonText?(s(),u(d,{key:0,variant:`secondary`,size:`sm`,onClick:handleButtonClick},{default:c(()=>[n(o(a.buttonText),1)]),_:1})):t(``,!0)])]))}});export{g as default};
//# sourceMappingURL=NodeConflictFooter-G3BXpc_N.js.map