import"./vendor-primevue-DxVRNMbC.js";import"./vendor-other-CyG3qq8S.js";import"./useFeatureFlags-CxRWjdi1.js";import"./api-DQLKc1Xa.js";import"./vendor-markdown-Cola12Wc.js";import"./colorUtil-Cth7eqhK.js";import"./i18n-DjV_9lZM.js";import{t as e}from"./SettingDialogHeader-DkxX_y37.js";export{e as default};