import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{pt as t}from"./vendor-primevue-DxVRNMbC.js";import"./vendor-firebase-CdLSXhbt.js";import{Dt as n,F as r,I as i,O as a,R as o,Vt as s,et as c,gt as l,j as u}from"./vendor-vue-core-X6q-rGJs.js";import"./vendor-other-CyG3qq8S.js";import"./useFeatureFlags-CxRWjdi1.js";import"./api-DQLKc1Xa.js";import"./vendor-markdown-Cola12Wc.js";import"./colorUtil-Cth7eqhK.js";import{n as d}from"./vendor-i18n-B5g6Drzm.js";import"./i18n-DjV_9lZM.js";import"./vendor-reka-ui-CHPbCe4i.js";import{t as f}from"./Button-C7dWyQyS.js";import{yn as p}from"./dialogService-Cqui0UMO.js";import"./systemStatsStore-D9aNY5gT.js";import"./useErrorHandling-BFB8eSj5.js";import{t as m}from"./dialogStore-CXD5Bcfy.js";import"./useCopyToClipboard-C74olorb.js";import"./vendor-tiptap-BXSIIPYY.js";import"./markdownRendererUtil-Bm7Umh6C.js";import"./useExternalLink-Cc30SNi3.js";var h={class:`flex w-full max-w-[360px] flex-col rounded-2xl border border-border-default bg-base-background`},g={class:`flex h-12 items-center justify-between border-b border-border-default px-4`},_={class:`m-0 text-sm font-normal text-base-foreground`},v=[`aria-label`],y={class:`px-4 py-4`},b={class:`m-0 text-sm text-muted-foreground`},x={class:`flex items-center justify-end gap-4 px-4 py-4`},S=o({__name:`RevokeInviteDialogContent`,props:{inviteId:{}},setup(e){let o=m(),S=p(),C=t(),{t:w}=d(),T=n(!1);function onCancel(){o.closeDialog({key:`revoke-invite`})}async function onRevoke(){T.value=!0;try{await S.revokeInvite(e.inviteId),o.closeDialog({key:`revoke-invite`})}catch(e){C.add({severity:`error`,summary:w(`g.error`),detail:e instanceof Error?e.message:void 0,life:3e3})}finally{T.value=!1}}return(e,t)=>(c(),u(`div`,h,[a(`div`,g,[a(`h2`,_,s(e.$t(`workspacePanel.revokeInviteDialog.title`)),1),a(`button`,{class:`cursor-pointer rounded border-none bg-transparent p-0 text-muted-foreground transition-colors hover:text-base-foreground focus-visible:outline-none focus-visible:ring-1 focus-visible:ring-secondary-foreground`,"aria-label":e.$t(`g.close`),onClick:onCancel},t[0]||=[a(`i`,{class:`pi pi-times size-4`},null,-1)],8,v)]),a(`div`,y,[a(`p`,b,s(e.$t(`workspacePanel.revokeInviteDialog.message`)),1)]),a(`div`,x,[i(f,{variant:`muted-textonly`,onClick:onCancel},{default:l(()=>[r(s(e.$t(`g.cancel`)),1)]),_:1}),i(f,{variant:`destructive`,size:`lg`,loading:T.value,onClick:onRevoke},{default:l(()=>[r(s(e.$t(`workspacePanel.revokeInviteDialog.revoke`)),1)]),_:1},8,[`loading`])])]))}});export{S as default};
//# sourceMappingURL=RevokeInviteDialogContent-wof04bsY.js.map