import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{O as t,R as n,Vt as r,b as i,et as a,j as o}from"./vendor-vue-core-X6q-rGJs.js";var s={class:`relative size-full overflow-hidden rounded`},c={class:`flex size-full flex-col items-center justify-center gap-2 bg-modal-card-placeholder-background transition-transform duration-300 group-hover:scale-105 group-data-[selected=true]:scale-105`},l={class:`text-base-foreground`},u=[`src`],d=n({__name:`MediaAudioTop`,props:{asset:{}},setup(e){return(e,n)=>(a(),o(`div`,s,[t(`div`,c,[n[1]||=t(`i`,{class:`icon-[lucide--music] text-3xl text-base-foreground`},null,-1),t(`span`,l,r(e.$t(`assetBrowser.media.audioPlaceholder`)),1)]),t(`audio`,{controls:``,class:`absolute bottom-0 left-0 w-full p-2`,src:e.asset.src,onClick:n[0]||=i(()=>{},[`stop`])},null,8,u)]))}});export{d as default};
//# sourceMappingURL=MediaAudioTop-BKeqCZrq.js.map