const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=["./i18n-BqJ9KHhY.js","./vendor-primevue-DxVRNMbC.js","./vendor-vue-core-X6q-rGJs.js","./rolldown-runtime-DCMCV6zW.js","./i18n-DjV_9lZM.js","./vendor-i18n-B5g6Drzm.js"])))=>i.map(i=>d[i]);
import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{ut as t}from"./vendor-primevue-DxVRNMbC.js";import{c as n,l as r}from"./vendor-vue-core-X6q-rGJs.js";import{t as i}from"./types-DW97iHDr.js";import{V as a,s as o}from"./vendor-vueuse-B_IQhD9R.js";import{r as s}from"./api-DQLKc1Xa.js";import{Fr as c,i as l,or as u}from"./dialogService-Cqui0UMO.js";import{t as d}from"./userStore-CGYKho9e.js";const f=n(`bootstrap`,()=>{let e=l(),n=c(),{isReady:f,error:p,execute:m}=o(async()=>{let{mergeCustomNodesI18n:e}=await t(async()=>{let{mergeCustomNodesI18n:e}=await import(`./i18n-BqJ9KHhY.js`);return{mergeCustomNodesI18n:e}},__vite__mapDeps([0,1,2,3,4,5]),import.meta.url);e(await s.getCustomNodesI18n())},void 0,{immediate:!1}),h=!1;function loadAuthenticatedStores(){h||(h=!0,e.load(),n.loadWorkflows())}async function startStoreBootstrap(){let e=d();if(await e.initialize(),i){let{isInitialized:e}=r(u());await a(e).toBe(!0)}let{needsLogin:t}=r(e);await a(t).toBe(!1),m(),loadAuthenticatedStores()}return{isI18nReady:f,i18nError:p,startStoreBootstrap}});export{f as t};
//# sourceMappingURL=bootstrapStore-Yy3FKFcc.js.map