import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{n as t}from"./types-DW97iHDr.js";function electronAPI(){return window.electronAPI}function showNativeSystemMenu(){electronAPI()?.showContextMenu()}function isNativeWindow(){return t&&!!window.navigator.windowControlsOverlay?.visible}export{isNativeWindow as n,showNativeSystemMenu as r,electronAPI as t};
//# sourceMappingURL=envUtil-CcEF5ALS.js.map