import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import"./vendor-primevue-DxVRNMbC.js";import{F as t,I as n,It as r,O as i,R as a,Vt as o,et as s,gt as c,it as l,j as u}from"./vendor-vue-core-X6q-rGJs.js";import"./vendor-other-CyG3qq8S.js";import{n as d}from"./vendor-i18n-B5g6Drzm.js";import"./i18n-DjV_9lZM.js";import"./vendor-reka-ui-CHPbCe4i.js";import{t as f}from"./Button-C7dWyQyS.js";import{t as p}from"./useExternalLink-Cc30SNi3.js";var m={class:`flex h-110 max-w-96 flex-col gap-4 p-2`},h={class:`mb-2 text-2xl font-medium`},g={class:`mb-4 text-base`},_={class:`flex items-center justify-between`},v={class:`flex gap-2`},y=a({__name:`ApiNodesSignInContent`,props:{apiNodeNames:{},onLogin:{type:Function},onCancel:{type:Function}},setup(e){let{t:a}=d(),{buildDocsUrl:y}=p(),handleLearnMoreClick=()=>{window.open(y(`/tutorials/api-nodes/faq`,{includeLocale:!0}),`_blank`)};return(e,d)=>{let p=l(`ApiNodesList`);return s(),u(`div`,m,[i(`div`,h,o(r(a)(`apiNodesSignInDialog.title`)),1),i(`div`,g,o(r(a)(`apiNodesSignInDialog.message`)),1),n(p,{"node-names":e.apiNodeNames},null,8,[`node-names`]),i(`div`,_,[n(f,{variant:`textonly`,onClick:handleLearnMoreClick},{default:c(()=>[t(o(r(a)(`g.learnMore`)),1)]),_:1}),i(`div`,v,[n(f,{variant:`secondary`,onClick:d[0]||=t=>e.onCancel?.()},{default:c(()=>[t(o(r(a)(`g.cancel`)),1)]),_:1}),n(f,{onClick:d[1]||=t=>e.onLogin?.()},{default:c(()=>[t(o(r(a)(`g.login`)),1)]),_:1})])])])}}});export{y as default};
//# sourceMappingURL=ApiNodesSignInContent-B6tbFhs0.js.map