import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{O as t,Vt as n,et as r,j as i}from"./vendor-vue-core-X6q-rGJs.js";import{t as a}from"./_plugin-vue_export-helper-fSAtQzP-.js";var o={},s={class:`flex w-full items-center justify-between p-4`},c={class:`flex items-center gap-2`},l={class:`m-0 text-sm`};function _sfc_render(e,a){return r(),i(`div`,s,[t(`div`,c,[a[0]||=t(`i`,{class:`icon-[lucide--triangle-alert] text-warning-background`},null,-1),t(`p`,l,n(e.$t(`importFailed.title`)),1)])])}var u=a(o,[[`render`,_sfc_render]]);export{u as default};
//# sourceMappingURL=ImportFailedNodeHeader-CdbZaUdi.js.map