import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import"./vendor-primevue-DxVRNMbC.js";import"./vendor-firebase-CdLSXhbt.js";import{D as t}from"./vendor-vue-core-X6q-rGJs.js";import"./vendor-other-CyG3qq8S.js";import{i as n}from"./useFeatureFlags-CxRWjdi1.js";import"./api-DQLKc1Xa.js";import"./vendor-markdown-Cola12Wc.js";import"./colorUtil-Cth7eqhK.js";import{o as r}from"./i18n-DjV_9lZM.js";import"./vendor-reka-ui-CHPbCe4i.js";import"./Button-C7dWyQyS.js";import{qt as i}from"./dialogService-Cqui0UMO.js";import"./systemStatsStore-D9aNY5gT.js";import"./useErrorHandling-BFB8eSj5.js";import"./dialogStore-CXD5Bcfy.js";import"./useCopyToClipboard-C74olorb.js";import"./vendor-tiptap-BXSIIPYY.js";import"./markdownRendererUtil-Bm7Umh6C.js";import"./useExternalLink-Cc30SNi3.js";var a=t(()=>{let e=[],t=n.value.server_health_alert;return t&&e.push({text:t.message,label:t.badge,variant:t.severity??`error`,tooltip:t.tooltip}),e.push({label:r(`g.beta`),text:`Comfy Cloud`}),e});i().registerExtension({name:`Comfy.Cloud.Badges`,get topbarBadges(){return a.value}});
//# sourceMappingURL=cloudBadges-DAMy5KUL.js.map